use `telerec`;

create table `rec_modules` (
  `module_id` int(10) unsigned  not null auto_increment,
  `name` varchar(255) not null,
  `displayname` varchar(255) not null,
  `admin` enum('yes', 'no') not null default 'no',
  `version` varchar(255) not null,
  primary key (`module_id`)
) character set utf8 collate utf8_unicode_ci;

create table `rec_main_menu` (
  `id` int(10) unsigned not null auto_increment,
  `label` varchar(255) not null,
  `parent_id` int(10) unsigned  default null,
  `module_id` int(10) unsigned  default null,
  `font_icon` varchar(255) default null,
  `sort`  int(10) unsigned not null,
  primary key (`id`),
  key `module_id` (`module_id`),
  key `parent_id` (`parent_id`),
  foreign key (`module_id`) references `rec_modules` (`module_id`) on delete cascade,
  foreign key (`parent_id`) references `rec_main_menu` (`id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_tenants` (
  `id` int(10) unsigned  not null auto_increment,
  `tenant` varchar(255) not null,
  `description` varchar(255) default null,
  `default` enum('yes', 'no') not null default 'no',
  `database_host` varchar(255) default null,
  `database_port` int(10) unsigned default null,
  `database_name` varchar(255) default null,
  `database_username` varchar(255) default null,
  `database_password` varchar(255) default null,
  primary key (`id`)
) character set utf8 collate utf8_unicode_ci;

create table `rec_themes` (
  `theme_id` int(10) unsigned not null auto_increment,
  `theme_name`  varchar(255) not null,
  `theme_value` varchar(255) not null,
  primary key (`theme_id`)
) character set utf8 collate utf8_unicode_ci;

create table `rec_users_profiles` (
  `id`  int(10) unsigned  not null auto_increment,
  `owner`  int(10) unsigned default null,
  `type` int(10) default null,
  `profile` varchar(255) not null,
  `allow_listen` enum('yes', 'no') not null default 'yes',
  `add_notes`  enum('yes', 'no') not null default 'yes',
  `add_flags`  enum('yes', 'no') not null default 'yes',
  `add_ref_number` enum('yes', 'no') not null default 'yes',
  `allow_delete` enum('yes', 'no') not null default 'no',
  `create_reports` enum('yes', 'no') not null default 'yes',
  `create_users` enum('yes', 'no') not null default 'no',
  `superadmin` enum('yes', 'no') not null default 'no',
  `default` enum('yes', 'no') not null default 'no',
  primary key (`id`)
) character set utf8 collate utf8_unicode_ci;

create table `rec_modules_restrictions` (
  `profile_id` int(10) unsigned not null,
  `module_id`  int(10) unsigned not null,
  unique key `role_id` (`profile_id`, `module_id`),
  key `module_id` (`module_id`),
  foreign key (`profile_id`) references `rec_users_profiles` (`id`) on delete cascade,
  foreign key (`module_id`) references `rec_modules` (`module_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_users` (
  `id` int(10) unsigned  not null auto_increment,
  `parent` int(10) unsigned default null,
  `type`  int(10) unsigned default null,
  `profile_id` int(10) unsigned default null,
  `tenant_id` int(10) unsigned default null,
  `name`  varchar(255) not null,
  `dept`  varchar(255) default null,
  `user`  varchar(255) not null,
  `extension_id`  int(10) default null,
  `password`  binary(64) default null,
  `notifications` varchar(255) default null,
  `locale` varchar(255) not null,
  `timezone`  varchar(255) not null,
  `startapp`  varchar(255) default null,
  `theme`  varchar(255) default null,
  `multitab`  enum('yes', 'no') not null default 'yes',
  `enable` enum('yes', 'no') not null default 'yes',
  primary key (`id`),
  key `parent` (`parent`),
  key `profile_id` (`profile_id`),
  key `tenant_id` (`tenant_id`),
  foreign key (`parent`) references `rec_users` (`id`) on delete cascade,
  foreign key (`profile_id`) references `rec_users_profiles` (`id`) on delete cascade,
  foreign key (`tenant_id`) references `rec_tenants` (`id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_sessions` (
  `session_id` binary(20) not null,
  `user_id` int(10) unsigned not null,
  `created` timestamp not null default current_timestamp,
  `modified` timestamp not null default '0000-00-00 00:00:00',
  primary key (`session_id`),
  key `modified` (`modified`),
  key `user_id` (`user_id`),
  foreign key (`user_id`) references `rec_users` (`id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_settings` (
  `setting_id` int(10) unsigned not null auto_increment,
  `module_id`  int(10) unsigned not null,
  `name` varchar(255) not null,
  `value`  varchar(255) default null,
  primary key (`setting_id`),
  unique key `module_id` (`module_id`, `name`),
  foreign key (`module_id`) references `rec_modules` (`module_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_teams` (
  `team_id`  int(10) unsigned not null  auto_increment,
  `description` varchar(255) not null,
  `flag_profile_id` int(10) not null,
  primary key (`team_id`)
) character set utf8 collate utf8_unicode_ci;

create table `rec_user_teams` (
  `user_id` int(10) unsigned not null,
  `team_id` int(10) unsigned not null,
  key `user_id` (`user_id`),
  foreign key (`user_id`) references `rec_users` (`id`) on delete cascade,
  foreign key (`team_id`) references `rec_teams` (`team_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_user_supervisors` (
  `user_id` int(10) unsigned not null,
  `supervisor_id` int(10) unsigned not null,
  foreign key (`supervisor_id`) references `rec_users` (`id`) on delete cascade,
  foreign key (`user_id`) references `rec_users` (`id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_extensions` (
  `extension_id` int unsigned not null auto_increment,
  `ombu_extension_id` int unsigned not null,
  `extension` varchar(255) not null,
  `ombu_extension_type` enum('extension', 'pass_through') not null default 'extension',
  `name`  varchar(255) not null,
  `team_id`  int(10) unsigned not null,
  `serial` binary(64) NOT NULL,
  primary key (`extension_id`),
  foreign key (`team_id`) references `rec_teams` (`team_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_filters` (
  `filter_id` int(10) not null auto_increment,
  `user_id` int(10) unsigned not null,
  `team_id` int(10) unsigned  default null,
  `description` varchar(255) default null,
  primary key (`filter_id`),
  foreign key (`user_id`) references `rec_users` (`id`) on delete cascade,
  foreign key (`team_id`) references `rec_teams` (`team_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_filter_items` (
  `filter_id` int(10) not null,
  `condition` varchar(255) default null,
  `search_by` varchar(255) default null,
  `value` varchar(255) default null,
  `mode`  varchar(255) default null,
  foreign key (`filter_id`) references `rec_filters` (`filter_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_filter_extensions` (
  `filter_id` int(10) not null,
  `extension_id` int(10) unsigned not null,
  foreign key (`extension_id`) references `rec_extensions` (`extension_id`) on delete cascade,
  foreign key (`filter_id`) references `rec_filters` (`filter_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_flags_profiles` (
  `flag_profile_id` int(10) not null auto_increment,
  `description` varchar(255) not null,
  primary key (`flag_profile_id`)
) character set utf8 collate utf8_unicode_ci;

create table `rec_flag_default_colors` (
  `color_id` int(10) unsigned not null auto_increment,
  `name` varchar(255) not null,
  `value` varchar(255) not null,
  primary key (`color_id`)
) character set utf8 collate utf8_unicode_ci;

create table `rec_flag_items` (
  `flag_id`  int(10) not null auto_increment,
  `flag_profile_id` int(10) not null,
  `name` varchar(255) not null,
  `color_id` int(11) unsigned not null,
  primary key (`flag_id`),
  foreign key (`color_id`) references `rec_flag_default_colors` (`color_id`) on delete cascade,
  foreign key (`flag_profile_id`) references `rec_flags_profiles` (`flag_profile_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_filter_flags` (
  `filter_id` int(10) default null,
  `flag_id` int(10) default null,
  key `filter_id` (`filter_id`),
  key `flag_id` (`flag_id`),
  foreign key (`flag_id`) references `rec_flag_items` (`flag_id`) on delete cascade,
  foreign key (`filter_id`) references `rec_filters` (`filter_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_recordings` (
  `call_id`  varchar(255) not null,
  `user_id`  int(10) unsigned  default null,
  `extension_id` int(10) unsigned  not null,
  `rating` int(10) default null,
  `reference` varchar(255) default null,
  `recfile_path` varchar(255) default null,
  foreign key (`user_id`) references `rec_users` (`id`) on delete cascade,
  foreign key (`extension_id`) references `rec_extensions` (`extension_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_recording_flags` (
  `call_id`  varchar(255) not null,
  `extension_id` int(10) unsigned  not null,
  `flag_id`  int(10) not null,
  key `flag_id` (`flag_id`),
  foreign key (`extension_id`) references `rec_extensions` (`extension_id`) on delete cascade,
  foreign key (`flag_id`) references `rec_flag_items` (`flag_id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_recording_notes` (
  `call_id`  varchar(255) not null,
  `extension_id` int(10) unsigned  not null,
  `note`  varchar(255) not null,
  `datetime` datetime  not null,
  `user_id`  int(10) unsigned  not null,
  foreign key (`extension_id`) references `rec_extensions` (`extension_id`) on delete cascade,
  foreign key (`user_id`) references `rec_users` (`id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_downloads` (
  `request_id`  int(10) unsigned not null auto_increment,
  `description` varchar(255) not null,
  `user_id` int(10) unsigned not null,
  `datetime` datetime  not null,
  `filename` varchar(255) not null,
  primary key (`request_id`),
  foreign key (`user_id`) references `rec_users` (`id`) on delete cascade
) character set utf8 collate utf8_unicode_ci;

create table `rec_schedules_profiles` (
  `schedule_id` int(10) unsigned not null auto_increment,
  `description` varchar(255) not null,
  `profile` varchar(255) default null,
  `minute`  varchar(255) default '*',
  `hour` varchar(255) default '*',
  `day`  varchar(255) default '*',
  `month` varchar(255) default '*',
  `weekday` varchar(255) default '*',
  primary key (`schedule_id`)
) character set utf8 collate utf8_unicode_ci;

create table `rec_ftp_conf` (
  `server`  varchar(255) not null,
  `port` varchar(255) not null,
  `user` varchar(255) not null,
  `password` varchar(255) not null,
  `upload_path` varchar(255) not null,
  `public_url` varchar(255) not null
) character set utf8 collate utf8_unicode_ci;

create table `rec_maintenance` (
  `convert_to_mp3` enum('yes', 'no') not null,
  `convert_to_mp3_cron` int(10) unsigned  not null,
  `move_after_convert` enum('yes', 'no') default 'no',
  `move_after_convert_target` varchar(255) not null,
  `clear_last_ndays`  varchar(255) not null,
  `clear_last_ndays_cron` int(10) unsigned default null,
  `clear_less_nseconds` varchar(255) not null,
  `clear_less_nseconds_cron`  int(10) unsigned default null
) character set utf8 collate utf8_unicode_ci;