/*!
 * Ombutel
 * plugins needed: bootstrap, jquery validation, jquery form, jquery ui, jquery ui touch and all extended from those
 */

var Validations = {
	ignore: ".ignore, :hidden",
	errorClass: "validations-tooltip",
	showErrors: function (errorMap, errorList) {
		$.each(this.validElements(), function (index, element) {
			var formElement = $(element);
			formElement.data("title", "");
			if (formElement.parent('.input-group').length) {
				var input_group = formElement.parent('.input-group');
				input_group.parent('.form-group').removeClass('has-error');
			} else {
				formElement.parent('.form-group').removeClass('has-error');
			}

			formElement.tooltip("destroy");
		});

		$.each(errorList, function (index, error) {
			var formElement = $(error.element);

			formElement.tooltip("destroy")
				.data("title", error.message);

			if (formElement.parent('.input-group').length) {
				var input_group = formElement.parent('.input-group');
				input_group.parent('.form-group').addClass('has-error');
			} else {
				formElement.parent('.form-group').addClass('has-error');
			}
			formElement.tooltip({
				trigger: 'hover focus click focusout',
				template: '<div class="tooltip validations-tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',
				content: function () {
					return $(this).prop('title');
				}
			});
		});
	}
};

var submitOptions = {
	beforeSubmit: formBeforeSubmit,
	success: processServerResponse,
	dataType: 'json',
	url: $(this).attr('action'),
	resetForm: false,
	error: processServerErrors
};

var repeatableSettings = {
	wrapper: '.repeat-wrapper',
	container: '.repeat-container',
	row: '.repeat-row',
	add: '.repeat-add',
	remove: '.repeat-remove',
	move: '.repeat-move',
	template: '.repeat-template'
};

var scrollSettings = {
	wheelSpeed: 2,
	wheelPropagation: true,
	minScrollbarLength: 20
};

var NProgressSettings = {
	speed: 200,
	minimum: 0.08,
	trickleRate: 0.02,
	trickleSpeed: 800,
	showSpinner: false
};

var rightMenuAnimation = {
	effect: 'slide',
	direction: 'right',
	duration: 200
};

var loginForm = $('#pbxlogin-form');

var bodyWidth;
var bodyHeight;
var docBody = $("body");
var spinner = $("#spinner-section");
var mainTabs = $("#app-main-tabs");
var modulesHeaderContent = $("#modules-content-header");
var modulesContent = $("#app-modules-content");
var globSearchInput = $("#app-search");
var rightMenu = $("#aside-nav-right");
var rightMenuList = rightMenu.find('ul');
var rightMenuTitle = rightMenu.find('h4');
var rightMenuFilter = rightMenu.find('input#filter-search-input');
var rightMenuClose = rightMenu.find('a#close-module-menu');
var Ombutel = $(document);
var isMultiTab;
var moduleCallBacks = {};

Ombutel.ready(OmbutelInit);

$(window).on('load resize', function () {
	bodyWidth = docBody.width();
	bodyHeight = Ombutel.height();
	spinner.fadeOut();
	spinner.remove();
	tooltipPBX();
	helpPopover();
	friendlyActionButtons();
	updateTabControls();
	mobileInteraction();
});

function OmbutelInit() {
	if (loginForm.length) {
		loginForm.validate(Validations);
	}
	bodyHeight = Ombutel.height();
	$(document).on('submit', 'form', formSubmitHandler);

	fnBrowserDetect();

	Ripple();

	registerEventCloseTabs();

	isMultiTab = !!(multi_tab === 'yes' || multi_tab === '1');
	noMultiTab();

	globSearchInput.keypress(function (e) {
		if (e.which == 13) {
			globalSearch($(this).val());
		}
	});

	$("#fire-search").click(function() {
		globalSearch(globSearchInput.val());
	});

	registerRightMenuEvents();

	tooltipPBX();

	registerMobileMainTabsEvents();

	tabsContextMenu();

	showStartUp();

	switchTenant();

	login();
}

function login(){
	$('.login-inputs').each(function(){
		$(this).on('blur', function(){
			if($(this).val().trim() != "") {
				$(this).addClass('has-val');
			}
			else {
				$(this).removeClass('has-val');
			}
		})
	});

	$('.show-pass').on('click', function(){
		let icon = $(this).find('i');
		let input = $(this).next('input');

		if(icon.hasClass('fa-eye')){
			icon.removeClass('fa-eye');
			icon.addClass('fa-eye-slash');
			input.attr('type', 'text');
		}else{
			icon.removeClass('fa-eye-slash');
			icon.addClass('fa-eye');
			input.attr('type', 'password');
		}
	});
}

function switchTenant() {
	var dropdown = $("#switch-tenant");
	dropdown.unbind('change');
	dropdown.on('change', function () {
		Cookies.set('sr_tenant', $(this).val(), {expires: 1});
		location.reload();
	})
}

function formSubmitHandler() {
	$(this).ajaxSubmit(submitOptions);
	return false;
}

function formBeforeSubmit() {
	showLoader();
}

function noMultiTab() {
	if (!isMultiTab) {
		modulesHeaderContent.removeClass('multi-tab').addClass('no-multi-tab').html('');
		modulesContent.removeClass('tab-content').html('');
	}
}

function showStartUp(){
	if(typeof startup != "undefined" && startup != ''){
		pbx_request(startup);
	}
}

function globalSearch(criterion) {
	if(criterion === null || criterion === ''){
		sendNotification('warning','Nothing to search');
		return;
	}
	pbx_request('search','get_content','get',criterion,'Search',true);
}

function registerRightMenuEvents() {
	Ombutel.on("click","button.btn-menu-mod", function () {
		showRightMenu();
	});

	$("#right-back-drop").on("click", function() {
		hideRightMenu();
	});

	rightMenuClose.on("click", function() {
		hideRightMenu();
	});
}

function pbx_request(item, method, mode, data, label, showTab) {
	var Obj = item;
	var ObjMethod = (method == null ? "get_content" : method);
	var postMode = (mode == null ? "add" : mode);
	var postData = (data == null ? 0 : data);
	var contentTabID = "tab_" + item;
	var tabLabel = (label == null ? $("#" + item).text() : label);
	var openTab = !!(showTab === null || typeof showTab === "undefined");
	if(showTab === true){
		openTab = true;
	}

	$.ajax({
		type: "POST",
		url: CallBack,
		dataType: 'json',
		data: {class: Obj, method: ObjMethod, mode: postMode, data: postData},
		beforeSend: function () {
			showLoader();
		},
		success: function (Response) {
			if (typeof Response.state !== 'undefined' && Response.state !== null) {
				if (Response.state === 'success' || Response.state === 'message') {
					if (!isMultiTab) {
						addModuleHeaderTitle(tabLabel);
					} else {
						if (openTab === true) {
							addPBXTab(contentTabID, tabLabel);
						}
					}
				}
			}
			processServerResponse(Response);
			delegatePBX();
		},
		error: processServerErrors
	});
}

function addModuleHeaderTitle(title) {
	if (!modulesHeaderContent.length) {
		sendNotification('error', '[HM7790] You did not define the Header Module Section', 2000);
		return false;
	}

	modulesHeaderContent.html('<h3 class="no-margin"> '+ title +' </h3>');
}

function addPBXTab(contentID, label) {
	//Close Welcome tabs, this is not necessary
	var welcomeTab = mainTabs.find('a[href="#welcome"]');
	if(welcomeTab.length){
		welcomeTab.parent().remove();
	}


	if (!mainTabs.length && !modulesContent.length) {
		sendNotification('error', '[T7890] You did not define the Tab Section', 2000);
		return false;
	}

	var contentTab = $("#" + contentID);

	if (!contentTab.length) {
		mainTabs.prepend('<li role="presentation">' +
		'<a href="#' + contentID + '" aria-controls="' + contentID + '" role="tab" data-toggle="tab"> ' + label + ' ' +
		'<i class="fa fa-close fa-fw fa-2x close-tab"></i>' +
		' </a> ' +
		'</li>');

		modulesContent.prepend('<div role="tabpanel" class="tab-pane fade" id="' + contentID + '"' + '> ' + label + ' </div>');
	} else {
		var tab = mainTabs.find('a[href="#' + contentID + '"]');
		var cloneTab = tab.parent('li').clone();
		tab.parent().remove();
		mainTabs.prepend(cloneTab);

	}

	mainTabs.find('a[href="#' + contentID + '"]').tab('show');
	updateTabControls();
	registerEventCloseTabs();
	registerEventOpenTabs();
}

function registerEventCloseTabs() {
	$(".close-tab").click(function () {
		var tabContentId = $(this).parent('a').attr("href");
		$(this).parent('a').parent('li').remove();
		$(tabContentId).remove();
		updateTabControls();
		showMainFirstTab();
	});
}

function registerEventOpenTabs(){
	mainTabs.find('a[data-toggle="tab"]').on('shown.bs.tab', function (e) {
		$("#box-mod-content").perfectScrollbar('update');
	});
}

function showMainFirstTab(){
	var tabToShow = mainTabs.find('a:first');
	if(tabToShow.length === 0) return;
	tabToShow.parent('li').show();
	tabToShow.tab('show');
}

function tabsContextMenu(){
	$("#app-main-tabs li").contextMenu({
		menuSelector: "#tab-context-menu",
		menuSelected: function (invokedOn, selectedMenu) {
			var action = selectedMenu.attr('id');
			var tag = invokedOn.prop('tagName');
			var contentId = null;
			var liElem = null;

			if(tag === 'A'){
				contentId = invokedOn.attr('href');
				liElem = invokedOn.parent('li');
			}else if(tag === 'I'){
				contentId = invokedOn.parent('a').attr('href');
				liElem = invokedOn.parent('a').parent();
			}else if(tag === 'LI'){
				contentId = invokedOn.find('a').attr('href');
				liElem = invokedOn;
			}else{
				return false;
			}

			var prev = liElem.prevAll('li');
			var next = liElem.nextAll('li');

			switch (action){
				case 'closeSelf':
					liElem.remove();
					$(contentId).remove();
					updateTabControls();
					showMainFirstTab();
					break;
				case 'closeOthers':
					prev.each(function(){
						var prevContentId = $(this).find('a').attr('href');
						$(this).remove();
						$(prevContentId).remove();
					});

					next.each(function(){
						var nextContentId = $(this).find('a').attr('href');
						$(this).remove();
						$(nextContentId).remove();
					});

					updateTabControls();
					showMainFirstTab();
					break;

				case 'closeRightTabs':
					next.each(function(){
						var nextContentId = $(this).find('a').attr('href');
						$(this).remove();
						$(nextContentId).remove();
					});

					updateTabControls();
					break;

				default:
					sendNotification('warning', 'Unhandled tab context menu action "' + action +'"');
					break;
			}
		}
	});
}


function registerMobileMainTabsEvents() {
	$("#tab-control-left").click(function() {
		var active = mainTabs.find('> .active');
		var prev = active.prev('li').find('a');
		if (prev.length) {
			prev.tab('show');
		} else {
			$(this).hide();
		}

		updateTabControls();
	});

	$("#tab-control-right").click(function() {
		var active = mainTabs.find('> .active');
		var next = active.next('li').find('a');
		if (next.length) {
			next.tab('show');
		} else {
			$(this).hide();
		}

		updateTabControls();

	});
}

function updateTabControls() {
	var controlLeft = $("#tab-control-left");
	var controlRight = $("#tab-control-right");
	var active = mainTabs.find('> .active');
	var prev = active.prev('li').find('a');
	var next = active.next('li').find('a');

	active.show();

	if (prev.length) {
		if (bodyWidth <= 480) {
			prev.parent('li').hide();
			controlLeft.show();
		} else {
			controlLeft.hide();
			prev.parent('li').show();
		}

	} else {
		controlLeft.hide();
	}

	if (next.length) {
		if (bodyWidth <= 480) {
			next.parent('li').hide();
			controlRight.show();
		} else {
			next.parent('li').show();
			controlRight.hide();
		}

	} else {
		controlRight.hide();
	}

}

function processServerResponse(data) {
	hideLoader();

	if (typeof data !== 'undefined' && data !== null) {
		switch (data.state) {
			case 'success':
				if (typeof data.notification !== 'undefined') {
					sendNotification('success', data.notification.text);
				}

				if (typeof data.html !== 'undefined') {
					if (typeof data.action !== 'undefined') {
						processReceivedData(data);
					} else {
						sendNotification('warning', 'No action set for html received');
					}
				}

				break;

			case 'error':
				if (typeof data.notification !== 'undefined') {
					sendNotification('error', data.notification.text);
				} else {
					sendNotification('error', 'Unexpected error received');
				}
				break;

			case 'message':
				sendNotification(data.notification.type, data.notification.text, data.notification.time);
				if(typeof data.notification.reload !== 'undefined' && data.notification.reload === true){
					showReloadButton();
				}
				break;
		}
	}
}

function processReceivedData(data) {
	switch (data.action) {
		case 'dialog':
			removeModalBackDrop();
			ShowDialog(data.dialog, data.html);
			break;
		case 'remove-dialog':
			removeModalBackDrop();
			RemoveDialog(data.dialog);
			break;
		case 'reload':
			ReloadPage(data);
			break;
		case 'puthtml':
			removeModalBackDrop();
			PutHtml(data.html, data.elem);
			break;
		case 'append':
			append_html(data.html, data.elem);
			break;
		case 'resetform':
			ResetForm(data.form);
			break;
		case 'main_app':
			removeModalBackDrop();
			main_app(data.module, data.html, data.css_files, data.js_files, data.elem, data.reload, data.menu);
			break;
		case 'app_menu':
			app_menu(data.dataItem);
			break;
		case 'dependentCombo':
			dependentCombo(data.options, data.child, data.parent, data.show_empty_first);
			break;
		case 'populate-dropdown':
			populateDropdown(data);
			break;
		case 'sysreload-applied':
			removeModalBackDrop();
			systemReloadApplied();
			break;
		case 'open_url':
			open_new_tab(data.url);
			break;
			break;
	}
}

function ShowDialog(dialog, html) {
	$("#" + dialog).remove();
	$("body").append(html);

	$("#" + dialog).modal('show');
}

function PutHtml(html, elem) {
	var elemId = $("#" + elem);
	elemId.html('');
	elemId.html(html);

	delegatePBX();
}

function append_html(html, elem){
	var elemId = $("#" + elem);
	elemId.append(html);

	delegatePBX();
}

function RemoveDialog(dialog) {
	var dialogModal = $("#" + dialog);
	dialogModal.modal('hide');
	removeModalBackDrop();
	dialogModal.remove();
}

function ReloadPage(data) {
	if (typeof data.time !== 'undefined') {
		setInterval(location.reload(), data.time)
	} else {
		location.reload();
	}

}

function ResetForm(form) {
	$("#" + form).reset();
}

function main_app(module, html, css_files, js_files, elem, reload, rightMenu) {
	if (rightMenu === 'hide') {
		rightMenuList.html('');
		hideRightMenu();
	}

	if(css_files.length > 0) {
		$.each(css_files, function(index, path) {
			$('<link rel="stylesheet" href="'+path+'" type="text/css" />').appendTo("head");
		});
	}


	$.each(js_files, function(index, file) {
		var path = 'modules/' + module + '/resource/js/' + file + '.js';
		$.getScript(path);
	});

	if (isMultiTab) {
		$("#" + elem).html(html);
	} else {
		modulesContent.html(html);
	}

	//This function must be exist for each theme
	mobileInteraction();

	$(".custom-modal").hide();
	if (reload) {
		showReloadButton();
	}

	delegatePBX();
}

function app_menu(menu_items) {
	rightMenuTitle.html(menu_items.title);
	rightMenuList.html('');

	if (menu_items.hasOwnProperty("items")) {
		var menu = menu_items.items;
		$.each(menu, function (index, item) {
			var params = 'onclick="javascript:pbx_request(\'' + menu_items.module + '\',\'get_content\',\'edit\',\'' + item.id + '\')"';
			if (item.hasOwnProperty("cust")) {
				params = item.cust;
			}

			var description = '', liClass = '';
			if ((typeof item.description === 'undefined') || (item.description === '' || item.description === null)) {
				liClass = 'no-desc';
                description = item.content;
			} else {
				description = item.description;
			}

			var image = item.img;
			if (item.hasOwnProperty("custimg"))
				image = (item.custimg !== null && typeof item.custimg !== "boolean") ? item.custimg : image;

            if(description.length > 23)
                description = description.substring(0, 23) + '...';

            var title = (item.description ? item.description : description);
			var output = '<li class="' + liClass + ' toltip data-toggle="popover" data-trigger="hover" title="' + title + '"> <a ' + params + '> ' +
				'<img src="' + image + '"/>' +
				' <div class="clear">' +
				' <span class="title"> ' + description + ' </span>' +
				' <span class="description"> ' + item.content + ' </span>' +
				' </div>' +
				'</a> </li>';

			rightMenuList.append(output);
		});

		rightMenuFilter.fastLiveFilter('#module-menu-items > ul', {
			timeout: 200
		});
	}

	return true;
}

function dependentCombo(itemsOptions, child, parent, show_empty_first) {
	//Clear Destination
	var childDropDown = $("." + child);
	childDropDown.html('');

	$.each(itemsOptions, function (index, item) {
		var output = '<option value="' + item.value + '">' + item.content + '</option>';
		$("." + child).append(output);
	});

	var comboParent = $("." + parent);
	if (comboParent.val() !== '') {
		var ParentSelected = comboParent.attr('data-selected');
		if (ParentSelected !== '' && ParentSelected === comboParent.val()) {
			var ChildSelected = $("." + child).attr('data-selected');

			$("." + child + " option[value='" + ChildSelected + "']").attr("selected", "selected");
		} else {
			if ($("." + child + " option:not(:empty):nth-child(1)").length === 0 && show_empty_first !== true) {
				$("." + child + " option:not(:empty):nth-child(2)").attr("selected", "selected");
			}
		}
	}

	childDropDown.trigger('change');
}

function sendRequest(functionToCall, data) {
	$.ajax({
		dataType: 'json',
		type: "POST",
		timeout: 60000,
		url: CallBack,
		data: {call: functionToCall, data: data},
		beforeSend: showLoader,
		success: processServerResponse,
		error: processServerErrors
	});

	return false;
}

function sendNotification(type, text, time) {
	var direction = 'top-right';
	var closeable = true;
	var delay = (type === null || typeof type === "undefined" ? 2000 : time);

	toastr.options = {
		"closeButton": true,
		"hideDuration": "1000",
		"positionClass": "toast-top-center",
		"preventDuplicates": true,
		"timeOut": time
	};

	switch (type) {
		case 'success':
			toastr.success(text);
			break;

		case 'warning':
			toastr.warning(text);
			break;

		case 'error':
			toastr.error(text);
			break;

		case 'info':
			toastr.info(text);
			break;
	}
}

function Ripple() {
	$(".ripple-me").click(function (evt) {
		var elem = $(this);
		$(".ripple").remove();
		elem.prepend("<span class='ripple'></span>");

		var display = elem.css("display");
		(display == 'inline' || display == 'inline-block') ? elem.css({display: 'inline-block'}) : elem.css({display: 'block'});
		var ripple = elem.find('.ripple');
		ripple.addClass('ripple-def-color');

		if ($(this).is('[ripple-color]')) {
			var rippleColor = this.getAttribute("ripple-color");
			if (rippleColor != "") {
				ripple.removeClass('ripple-def-color');
				ripple.addClass(rippleColor);
			}
		}

		ripple.removeClass('animate');
		if (!ripple.width() && !ripple.height()) {
			var max = Math.max(elem.outerWidth(), elem.outerHeight());
			ripple.css({width: max + 'px', height: max + 'px'});
		}

		var x = evt.pageX - elem.offset().left - ripple.width() / 2;
		var y = evt.pageY - elem.offset().top - ripple.height() / 2;
		ripple.css({top: y + 'px', left: x + 'px'});
		setTimeout(function () {
			ripple.addClass('animate');
		}, 1);
	});
}

function hideRightMenu() {
	$("#right-back-drop").hide();
	rightMenuFilter.val(null);
	rightMenu.hide(rightMenuAnimation);
}

function showRightMenu() {
	$("#right-back-drop").show();
	rightMenuFilter.val(null);
	rightMenu.show(rightMenuAnimation);
}

function delegatePBX() {
	var tabList = $(".tabs_list");
	var bootstrapToggle = $(".bootstrap-toggle");
	var multiSelect = $(".multiselect");
	var tPicker = $(".jui-timepicker, .timepicker");
	var dPicker = $('.datepicker');
	var comboMultiple = $('.combo-multiple');
	var comboTags = $('.combo-tags');
	var comboWithSearch = $(".with-search");
	var rating = $('.rating');

	if (tabList.length) {
		tabList.on("click", "a", function (e) {
			e.preventDefault();
			$(this).tab('show');
		});
	}

	if (bootstrapToggle.length) {
		bootstrapToggle.bootstrapToggle({
			onstyle: 'success',
			width: 70
		});
	}

	if (multiSelect.length) {
		multiSelect.multiselect({
			'sortable': 'both'
		});
	}

	if (tPicker.length) {
		tPicker.timepicker().removeClass('jui-timepicker timepicker');
	}

	if (dPicker.length) {
		dPicker.datepicker({
			dateFormat: "yy-mm-dd",
			changeMonth: true,
			changeYear: true
		});
	}

	if (comboMultiple.length) {
		comboMultiple.select2({
			width: '100%'
		});
	}

	if (comboTags.length) {
		comboTags.select2({
			tags: true,
			width: '100%',
			tokenSeparators: [',', ' ']
		});
	}

	if(comboWithSearch.length){
		if(comboWithSearch.data('select2')){
			comboWithSearch.select2('destroy');
		}

		comboWithSearch.select2({
			theme: "bootstrap"
		});
	}

	helpPopover();

	friendlyActionButtons();

	tooltipPBX();

	if (typeof themeDelegate !== 'undefined' && $.isFunction(themeDelegate)) {
		themeDelegate();
	}

	if(mainTabs.length){
		tabsContextMenu();
	}

	recording_table_interaction();
}

function processServerErrors(data) {
	$('#error-modal-handle').find('.modal-body').html(data.responseText);
	hideLoader();
	$('#error-modal-handle').modal('show');
	console.log(data.responseText);
}

function multiple_select(combo, formElem, formTab, separator) {
	var selectedValues;

	separator = (separator === undefined || separator === null ? '\n' : separator);
	var selectedItems = $("#" + combo + " :selected");
	var formElement = (isMultiTab ? $("#" + formTab + " #" + formElem) : $("#" + formElem));

	switch (separator) {
		case "\n":
			selectedValues = "";

			selectedItems.each(function () {
				selectedValues += $(this).val() + "\n";
			});

			formElement.val(selectedValues);
			break;

		case ",":
			selectedValues = [];
			selectedItems.each(function () {
				selectedValues.push($(this).val());
			});

			formElement.val(selectedValues);
			break;

		default:
			break;
	}
}

function tooltipPBX() {
	if (bodyWidth <= 1200) {
		destroyTooltips();
	} else {
		$(".tooltip-pbx").tooltip({
			content: function () {
				return $(this).prop('title');
			}
		});
	}
}

function showLoader() {
	NProgress.configure(NProgressSettings);
	NProgress.start();
}

function hideLoader() {
	NProgress.done();
}

function removeModalBackDrop(){
	$('.modal-backdrop').remove();
}

function destroyTooltips(){
	$(".tooltip-pbx").tooltip('destroy');
}

function helpPopover(){
	var helpPopOver = $('.help-popover');

	if (bodyWidth >= 1200 && bodyHeight >= 750) {
		if(helpPopOver.length){
			helpPopOver.popover({
				html:true,
				container: 'body',
				placement: 'auto top',
				content: function() {
					return $(this).attr('title').html();
				},
				delay: {
					"show": 100,
					"hide": 100
				}
			});

			helpPopoverChangMode(helpPopOver, 'desktop');
		}
	}else{
		helpPopoverChangMode(helpPopOver, 'mobile');
		helpPopOver.popover('hide');
		helpPopOver.popover('destroy');
	}
}

function helpPopoverChangMode(helpPopOver,mode){
	helpPopOver.each(function(){
		var elem = $(this);
		elem.removeAttr('for');
		var helpContent = elem.data('content');
		var lblTitle = elem.text();
		var helpTitle = lblTitle.replace('*', '');

		if(mode === 'mobile'){
			elem.attr('title','Click for help');
			elem.unbind("click");
			elem.on('click',function(){
				BootstrapDialog.show({
					type: 'help-form-modal',
					title: '<h4 class="modal-title"> <i class="fa fa-fw fa-info-circle"></i>' + helpTitle + '</h4>',
					message: helpContent
				});
			});
		}else{
            elem.attr('title',null);
			elem.attr('data-original-title', helpTitle);
			elem.unbind("click");
		}
	});
}

function friendlyActionButtons(){
	var formActions = $('.frm-actions');
	if(formActions.length < 0){
		console.log(' -> Do not have actions this form');
		return;
	}


	if(bodyWidth <= 680){
		formActions.each(function($i, $e){
			var li = [];
			$(this).find('.btn').each(function($i, $e){
				if($(this).hasClass('frm-btn-action') || $(this).hasClass('mobile-action-list-btn')){
					return true;
				}

				var liItem = $("<li></li>").html($(this).clone().addClass('mobile-action-list-btn').removeClass('hidden'));
				$(this).addClass('hidden');
				li.push(liItem[0]);
			});

			//Create the new button
			var btngroup = $("<div></div>", {"class": "mobile-action-button btn-group dropup"});
			var button = $("<button></button>", {
				"class": "btn frm-btn-action btn-sm dropdown-toggle",
				"type": "button",
				"data-toggle": "dropdown",
				"aria-haspopup": "true",
				"aria-expanded": "false"
			}).html("<i class='fa fa-ellipsis-v fa-fw'></i> Actions");
			var ul = $("<ul></ul>",{"class": "dropdown-menu dropdown-menu-right mobile-actions-list"});
			ul.html(li);
			btngroup.html(button);
			btngroup.append(ul);

			var mobileButton = $(this).find('.mobile-action-button');
			if(mobileButton.length){
				mobileButton.remove();
			}

			$(this).append(btngroup);
		});
	}else{
       formActions.each(function($i, $e){
		   var mobileButton = $(this).find('.mobile-action-button');
		   if(mobileButton.length){
			   mobileButton.remove();
		   }
		   $(this).find('.btn').each(function($i, $e){
			   $(this).removeClass('hidden');
		   });
	   });
	}
}

function create_modal(title, accept) {
	var button = $("<button>").attr({"type" : "button", "data-dismiss" : "modal"});
	var modal = $("<div>").addClass("modal fade").attr("role", "dialog").append(
		$("<div>").addClass("modal-dialog").append(
			$("<div>").addClass("modal-content").append(
				$("<div>").addClass("modal-header").append(
					button.clone().addClass("close").append($("<span>").html("&times;")),
					$("<h4>").addClass("modal-title").html(title)
				),
				$("<div>").addClass("modal-body"),
				$("<div>").addClass("modal-footer").append(
					button.clone().addClass("btn btn-default").html(cancel_button_label),
					button.clone().addClass("btn btn-primary").html(accept_button_label)
				)
			)
		)
	);
	modal.on("hidden.bs.modal", function() { modal.remove(); });
	modal.on("click", ".btn-primary", function() { accept.apply(modal); });
	$("body").append(modal);
	return modal;
}

function multiselect_modal(title, element, accept) {
	var multiselect = create_modal(modal_select_label + ' ' + title, accept);
	var copy = element.clone().removeAttr("id name");
	copy.val(element.val()); // Workaround
	multiselect.find(".modal-body").append(copy);
	copy.multiselect({searchable: true});
	multiselect.modal();
}

$(function() {
	$("#app-content").on("change", ".imageupload input[type='file']", function() {
		var parent = $(this).closest(".imageupload");
		if (window.FileReader) {
			if (this.files instanceof FileList && this.files.length > 0) {
				var reader = new FileReader();
				reader.onload = function() {
					parent.find(".preview img:not(:last-of-type)").remove();
					parent.find(".preview").prepend(
						$("<img>").attr("src", this.result)
					);
					parent.removeClass("default");
				};
				reader.readAsDataURL(this.files[0]);
			}
		} else {
			parent.removeClass("default");
		}
	}).on("click", ".imageupload .remove", function() {
		var parent = $(this).closest(".imageupload");
		parent.find("input[type='file'],input[type='hidden']").each(function() { this.value = ""; });
		parent.find(".preview img:not(:last-of-type)").remove();
		parent.addClass("default");
		console.log(parent.find("input[type='file']").val());
	}).on("change", ".fileupload input[type='file']", function() {
		$(this).closest(".fileupload").find(".form-control").html(this.value);
	}).on("click", ".formset", function() {
		var formgroup = $(this).closest(".form-group");
		var select = formgroup.find("select");
		var map = {};
		select.find("option").each(function(index, option) { map[option.value] = option.text; });
		multiselect_modal(
			formgroup.find(".control-label").html(),
			select,
			function() {
				select.empty().append($(this).find("select option").clone());
				var values = select.val();
				if (values != null) {
					values = values.map(function(value) { return map[value]; }).join(",");
				}
				formgroup.find(".form-control").html(values);
			}
		);
		return false;
	});
});

function recording_table_interaction() {
	Ombutel.on('click', '.rating', function(e) {
		var recording_id = $(this).data('recording-id');
		var rating = $(this).raty('score');
		$.ajax({
			type: "POST",
			url: CallBack,
			dataType: 'json',
			data: {class: 'search_calls', method: 'set_rating', mode: "get", data: {'recording_id' : recording_id, 'rating' : rating}},
			success: function (Response) {
			}
		});
		e.stopImmediatePropagation();
	}).on('click', '.play-recording-btn', function(e) {
		Ombutel.find('.rec-table').find('tr').css('background', 'transparent');
		$(this).closest('tr').css('background', 'rgba(0,0,0,0.1)');
		$.ajax({
			type: "POST",
			url: CallBack,
			dataType: 'json',
			data: {class: 'search_calls', method: 'play_recording', data: $(this).closest('tr').data('cdr-id')},
			complete: function (result) {

				/*var modal_rec_player = '#modal-recording-player';
				$(modal_rec_player).remove();
				$('body').append(result.responseText);
				$(modal_rec_player).modal('show');*/
				if(typeof result.responseJSON !== 'undefined'){
					var response = result.responseJSON;
					var modal_rec_player = '#modal-recording-player';
					$(modal_rec_player).remove();
					if(response.status === 'success'){
						$('body').append(response.html);
						$(modal_rec_player).modal('show');
					}else{
						sendNotification('error', response.message)
					}
				}
			}
		});
		e.stopImmediatePropagation();
	}).on('click', '.show-email-form', function(e) {
		var email_form = $('.email-form-container');
		if(email_form.attr('expanded')) {
			email_form.hide(200).removeAttr('expanded');
		} else {
			email_form.show(200).attr('expanded', true);
			e.stopImmediatePropagation();
		}
	}).on('click', '.modal-recording-form .send-note', function(e) {
		var result_text = '';
		$.ajax({
			type: "POST",
			url: CallBack,
			dataType: 'json',
			data: {class: 'search_calls', method: 'send_notes', mode: "send_notes", data: {
				'recording_id' : $(this).data('recording-id'),
				'email' : $('#email').val(),
				'body' : $('#body').val()
			}},
			success: function (result) {
				$('#email').val('');
				$('#body').val('');
				result_text = (result === 'success' ? 'Notes successfully sent.' : 'Error sending notes.');
				Ombutel.find('.email-status').text(result_text);
				$('.email-success').show(200);
			}
		});
		e.stopImmediatePropagation();
	}).on('click', '.modal-recording-form .new-note', function() {
		$(this).attr('disabled', 'disabled').addClass('disabled');
		$('#notes').val('').removeAttr('readonly').focus();
		$('.save-note').removeAttr('disabled').removeClass('disabled');
	}).on('click', '.modal-recording-form .btn-primary, .modal-search-calls-form .btn-primary', function() {
		Ombutel.find('.modal-recording-form').modal('hide');
		Ombutel.find('.modal-search-calls-form').modal('hide');
	}).on('click', '.modal-module-delete .btn-danger', function() {
		var modal = Ombutel.find('.modal-module-delete');
		if(modal.find('#filter_id').length) {
			var recording_id = modal.find('#filter_id').val();
			Ombutel.find("tr[data-recording-id='"+recording_id+"']").remove();
			modal.modal('hide');
		}
	}).on('click', '.recording-icon', function() {
		Ombutel.find('.rec-table').find('tr').css('background', 'transparent');
		$(this).closest('tr').css('background', 'rgba(0,0,0,0.1)');
	});
}

function add_note(recording_id, note) {
	$.ajax({
		type: "POST",
		url: CallBack,
		dataType: 'json',
		data: {class: 'search_calls', method: 'put_actions', mode: "add_note",
			data: {
				'recording_id' : recording_id,
				'note' : note}
			},
		success: function (notes) {
			Ombutel.find('#notes').val(notes).attr('readonly', 'readonly');
		}
	});

	$('.save-note').attr('disabled', 'disabled').addClass('disabled');
	$('.new-note').removeAttr('disabled').removeClass('disabled');
}

function open_new_tab(url){
	var win = window.open(url,'_blank');
	/*window.setTimeout(function(){
		win.close();
	}, 1000);*/
}

function app_update(btn) {
	btn.addClass('loading disabled');
	var old_btn_text = btn.text();
	var action = btn.attr('data-action');
	btn.text(btn.attr('data-updating-text'));

	$.ajax({
		type: 'post',
		url: window.location.pathname,
		data: {call: 'update_app'},
		success: function (response) {
			var data = JSON.parse(response);
			if (data.status === 'updated') {
				location.reload();
			} else {
				btn.text(old_btn_text);
				btn.removeClass('loading disabled');
				sendNotification('error', data.message);
			}
		}
	})
}

function addModuleCallBack(name, callback){
	moduleCallBacks[name] = callback;
}

function launchModuleCallBack(name) {
	if(name in moduleCallBacks){
		console.log('launching callback: ' + name);
		moduleCallBacks[name]();
	}else{
		console.log('Callback ' + name + ' does not exists');
	}
}

function populateDropdown(data) {
	var form = $(data.form);
	var dropdown = form.find(data.dropdown);
	var options = data.options;
	var selectedOption = dropdown.attr('data-selected');

	dropdown.html('');

	$.each(options, function (index, item) {
		var option = '';
		option += '<option value="'+ item.value +'"';
		if(typeof item.params !== 'undefined') {
			$.each(item.params, function (param_index, param_val){
				option += ' '+ param_index +'="'+ param_val +'"';
			});
		}

		if((typeof selectedOption !== 'undefined' && selectedOption !== '') && item.value === selectedOption){
			option += ' selected="selected"';
		}

		option += '> ' + item.content + '</option>';

		dropdown.append(option);
	});

	dropdown.trigger('change');
}

/**
 * It detects the current browser brand and add it as class to the application body
 */
function fnBrowserDetect(){
	let userAgent = navigator.userAgent;
	let browserName;

	if(userAgent.match(/chrome|chromium|crios/i)){
		browserName = "chrome";
	}else if(userAgent.match(/firefox|fxios/i)){
		browserName = "firefox";
	}  else if(userAgent.match(/safari/i)){
		browserName = "safari";
	}else if(userAgent.match(/opr\//i)){
		browserName = "opera";
	} else if(userAgent.match(/edg/i)){
		browserName = "edge";
	}else{
		browserName="unknown";
	}

	$("body").addClass(browserName)
	console.log("You are using "+ browserName +" browser");
}